@@ -19,11 +19,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 sub databaseName {
@@ -242,9 +242,22 @@ sub generateScript {
         my @outVals = () ;
 #warn Dumper @{$ra_row} ;        
         for ( my $i = 0; $i < scalar @{$ra_row}; $i++ ) {
-#warn Dumper $ra_row->[$i] ;        
-            $ra_row->[$i] = ( defined $ra_row->[$i] ) ? $ra_row->[$i] : "null" ;
-            $outVals[$i] = ( $ColumnNumericity[$i] == 1 ) ? $ra_row->[$i] : $dbh->quote($ra_row->[$i]) ;
+#warn Dumper $ra_row->[$i] ;    
+#warn Dumper $ColumnNumericity[$i] ;
+#            $ra_row->[$i] = ( defined $ra_row->[$i] ) ? $ra_row->[$i] : "null" ;
+            
+            if ( ( $ColumnNumericity[$i] == 1 ) and ( not ( defined ($ra_row->[$i]) ) ) ) {
+                $outVals[$i] = 'null' ;  
+            }
+            if ( ( $ColumnNumericity[$i] == 0 ) and ( not ( defined ($ra_row->[$i]) ) ) ) {
+                $outVals[$i] = 'null' ;  
+            }
+            if ( ( $ColumnNumericity[$i] == 1 ) and (     ( defined ($ra_row->[$i]) ) ) ) {
+                $outVals[$i] = $ra_row->[$i]  ;  
+            }
+            if ( ( $ColumnNumericity[$i] == 0 ) and (     ( defined ($ra_row->[$i]) ) ) ) {
+                $outVals[$i] = $dbh->quote($ra_row->[$i])  ;  
+            }
         }
         #my @outVals = map { $ColumnNumericity{$_} == 1 ? $_ : $dbh->quote($_)  } @{$ra_row};
         my $line = do{ local $" = ", "; "@outVals" } ;
